@@ -4,15 +4,22 @@
 #ifndef CHEMFILES_FRAME_HPP
 #define CHEMFILES_FRAME_HPP
 
-#include "chemfiles/exports.hpp"
+#include <string>
+#include <vector>
+
+#include "chemfiles/exports.h"
 #include "chemfiles/types.hpp"
 #include "chemfiles/external/span.hpp"
 #include "chemfiles/external/optional.hpp"
 
 #include "chemfiles/Topology.hpp"
 #include "chemfiles/UnitCell.hpp"
+#include "chemfiles/Connectivity.hpp"
+#include "chemfiles/Property.hpp"
+#include "chemfiles/Residue.hpp"
 
 namespace chemfiles {
+class Atom;
 
 /// A frame contains data from one simulation step The Frame class holds data
 /// from one step of a simulation: the current topology, the positions, and the
@@ -24,7 +31,7 @@ namespace chemfiles {
 /// * ``cell`` is an infinite unit cell;
 /// * ``topology`` is empty, and contains no data;
 /// * ``positions`` is filled with zeros;
-/// * ``velocities`` is the nullopt variant of :cpp:class:`chemfiles::optional`.
+/// * ``velocities`` is the ``nullopt`` variant of :cpp:class:`chemfiles::optional`.
 ///
 /// @endverbatim
 ///
@@ -104,11 +111,6 @@ public:
 
     /// Get the positions of the atoms in this frame.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// A :cpp:class:`chemfiles::span` is a view inside a vector allowing
-    /// mutation of the values, but no memory allocation.
-    /// @endverbatim
-    ///
     /// @example{frame/positions.cpp}
     span<Vector3D> positions() {
         return positions_;
@@ -132,14 +134,6 @@ public:
     /// Get an velocities of the atoms in this frame, if this frame contains
     /// velocity data.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returna an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    ///
-    /// A :cpp:class:`chemfiles::span` is a view inside a vector allowing
-    /// mutation of the values, but no memory allocation.
-    /// @endverbatim
-    ///
     /// @example{frame/velocities.cpp}
     optional<span<Vector3D>> velocities() {
         if (velocities_) {
@@ -364,11 +358,6 @@ public:
     /// If no property with the given `name` is found, this function returns
     /// `nullopt`.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returns an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
     /// @example{frame/get.cpp}
     optional<const Property&> get(const std::string& name) const {
         return properties_.get(name);
@@ -383,11 +372,6 @@ public:
     /// If a property with the given `name` is found, but has a different kind,
     /// this function emits a warning and returns `nullopt`.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returns an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
     /// @example{frame/get.cpp}
     template<Property::Kind kind>
     optional<typename property_metadata<kind>::type> get(const std::string& name) const {
