@@ -4,13 +4,16 @@
 #ifndef CHEMFILES_FORMAT_MOL2_HPP
 #define CHEMFILES_FORMAT_MOL2_HPP
 
+#include <cstdint>
+#include <string>
 #include <unordered_map>
 
-#include "chemfiles/Format.hpp"
 #include "chemfiles/File.hpp"
-#include "chemfiles/Residue.hpp"
+#include "chemfiles/Format.hpp"
+#include "chemfiles/Residue.hpp"  // IWYU pragma: keep
 
 namespace chemfiles {
+class Frame;
 
 /// [MOL2][MOL2] file format reader and writer.
 ///
@@ -18,19 +21,14 @@ namespace chemfiles {
 /// `END` records, separating the steps.
 ///
 /// [MOL2]:
-class MOL2Format final: public Format {
+class MOL2Format final: public TextFormat {
 public:
-    MOL2Format(std::string path, File::Mode mode, File::Compression compression);
+    MOL2Format(std::string path, File::Mode mode, File::Compression compression):
+        TextFormat(std::move(path), mode, compression) {}
 
-    MOL2Format(const MOL2Format&) = delete;
-    MOL2Format& operator=(const MOL2Format&) = delete;
-    MOL2Format(MOL2Format&&) = default;
-    MOL2Format& operator=(MOL2Format&&) = default;
-
-    void read_step(size_t step, Frame& frame) override;
-    void read(Frame& frame) override;
-    void write(const Frame& frame) override;
-    size_t nsteps() override;
+    void read_next(Frame& frame) override;
+    void write_next(const Frame& frame) override;
+    optional<uint64_t> forward() override;
 
 private:
     // Read Atoms
@@ -39,12 +37,8 @@ private:
     // Read Bonds
     void read_bonds(Frame& frame, size_t nbonds);
 
-    std::unique_ptr<TextFile> file_;
     /// Map of residues, indexed by residue id.
     std::unordered_map<size_t, Residue> residues_;
-    /// Storing the positions of all the steps in the file, so that we can
-    /// just `seekg` them instead of reading the whole step.
-    std::vector<std::streampos> steps_positions_;
 };
 
 template<> FormatInfo format_information<MOL2Format>();
